@@ -15,13 +15,15 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed-single.c,v 1.28 2004/11/02 20:56:55 chpe Exp $
+ *  $Id: ephy-embed-single.c,v 1.33 2005/01/30 15:20:35 chpe Exp $
  */
 
 #include "config.h"
 
 #include "ephy-embed-single.h"
+#include "ephy-embed-type-builtins.h"
 #include "ephy-marshal.h"
+#include "ephy-signal-accumulator.h"
 
 static void ephy_embed_single_iface_init (gpointer g_class);
 
@@ -55,6 +57,28 @@ ephy_embed_single_iface_init (gpointer g_class)
 
 	if (initialised == FALSE)
 	{
+/**
+ * EphyEmbedSingle::new-window:
+ * @single:
+ * @parent_embed: the #EphyEmbed requesting the new window, or %NULL
+ * @mask: a #EphyEmbedChrome
+ *
+ * The ::new_window signal is emitted when a new window needs to be opened.
+ * For example, when a JavaScript popup window was opened.
+ *
+ * Return a new #EphyEmbed.
+ **/
+	g_signal_new ("new-window",
+		      EPHY_TYPE_EMBED_SINGLE,
+		      G_SIGNAL_RUN_FIRST | G_SIGNAL_RUN_LAST,
+		      G_STRUCT_OFFSET (EphyEmbedSingleIface, new_window),
+		      ephy_signal_accumulator_object, ephy_embed_get_type,
+		      ephy_marshal_OBJECT__OBJECT_FLAGS,
+		      GTK_TYPE_WIDGET,
+		      2,
+		      GTK_TYPE_WIDGET,
+		      EPHY_TYPE_EMBED_CHROME);
+
 /**
  * EphyEmbedSingle::handle_content:
  * @single:
@@ -96,6 +120,53 @@ ephy_embed_single_iface_init (gpointer g_class)
 		      1,
 		      G_TYPE_BOOLEAN);
 
+/**
+ * EphyEmbedSingle::add-sidebar:
+ * @single:
+ * @url: The url of the sidebar to be added
+ * @title: The title of the sidebar to be added
+ *
+ * The ::add-sidebar signal is emitted when the user clicks a javascript link that
+ * requests adding a url to the sidebar.
+ **/
+	g_signal_new ("add-sidebar",
+		      EPHY_TYPE_EMBED_SINGLE,
+		      G_SIGNAL_RUN_LAST,
+		      G_STRUCT_OFFSET (EphyEmbedSingleIface, add_sidebar),
+		      g_signal_accumulator_true_handled, NULL,
+		      ephy_marshal_BOOLEAN__STRING_STRING,
+		      G_TYPE_BOOLEAN,
+		      2,
+		      G_TYPE_STRING,
+		      G_TYPE_STRING);
+
+/**
+ * EphyEmbedSingle::check_content:
+ * @single: the #EphyEmbedSingle
+ * @type: the type of content (an #EphyContentCheckType)
+ * @address: the address of the content
+ * @requesting_address: the address of the requesting content (may be empty)
+ * @mime_type_guess: a guess of the mime type of the content (may be empty)
+ *
+ * The ::check-content signal is emitted when Epiphany loads any content from
+ * anywhere.
+ *
+ * If a connected callback returns %TRUE, the
+ * signal emission will stop, and the load be aborted.
+ **/
+	g_signal_new ("check_content",
+		      EPHY_TYPE_EMBED_SINGLE,
+		      G_SIGNAL_RUN_FIRST | G_SIGNAL_RUN_LAST,
+		      G_STRUCT_OFFSET (EphyEmbedSingleIface, check_content),
+		      g_signal_accumulator_true_handled, NULL,
+		      ephy_marshal_BOOLEAN__ENUM_STRING_STRING_STRING,
+		      G_TYPE_BOOLEAN,
+		      4,
+		      EPHY_TYPE_CONTENT_CHECK_TYPE,
+		      G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE,
+		      G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE,
+		      G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE);
+
 	initialised = TRUE;
 	}
 }
