@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ContentHandler.cpp,v 1.75 2004/12/31 16:09:39 chpe Exp $
+ *  $Id: ContentHandler.cpp,v 1.76 2005/01/28 22:23:38 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -62,18 +62,18 @@
 #ifdef MOZ_NSIMIMEINFO_NSACSTRING_
 GContentHandler::GContentHandler()
 {
-	LOG ("GContentHandler ctor (%p)", this)
+	LOG ("GContentHandler ctor (%p)", this);
 }
 #else
 GContentHandler::GContentHandler() : mMimeType(nsnull)
 {
-	LOG ("GContentHandler ctor (%p)", this)
+	LOG ("GContentHandler ctor (%p)", this);
 }
 #endif
 
 GContentHandler::~GContentHandler()
 {
-	LOG ("GContentHandler dtor (%p)", this)
+	LOG ("GContentHandler dtor (%p)", this);
 
 #ifndef MOZ_NSIMIMEINFO_NSACSTRING_
 	if (mMimeType)
