@@ -38,7 +38,7 @@
  *
  * ***** END LICENSE BLOCK *****
  *
- * $Id: MozDownload.cpp,v 1.59 2005/01/05 20:57:00 chpe Exp $
+ * $Id: MozDownload.cpp,v 1.60 2005/01/28 22:23:38 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -69,12 +69,12 @@ MozDownload::MozDownload() :
 	mEmbedPersist(nsnull),
 	mDownloadState(EPHY_DOWNLOAD_INITIALISING)
 {
-	LOG ("MozDownload ctor (%p)", (void *) this)
+	LOG ("MozDownload ctor (%p)", (void *) this);
 }
 
 MozDownload::~MozDownload()
 {
-	LOG ("MozDownload dtor (%p)", (void *) this)
+	LOG ("MozDownload dtor (%p)", (void *) this);
 
 	NS_ASSERTION (!mEphyDownload, "MozillaDownload still alive!");
 }
