@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-file-helpers.c,v 1.24 2005/01/19 21:39:00 chpe Exp $
+ *  $Id: ephy-file-helpers.c,v 1.25 2005/01/28 22:24:03 chpe Exp $
  */
 
 #include "config.h"
@@ -229,7 +229,7 @@ ephy_file_helpers_shutdown (void)
 
 	if (mime_table != NULL)
 	{
-		LOG ("Destroying mime type hashtable")
+		LOG ("Destroying mime type hashtable");
 		g_hash_table_destroy (mime_table);
 		mime_table = NULL;
 	}
