@@ -15,12 +15,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-gui.c,v 1.22.4.6 2004/12/20 12:30:03 chpe Exp $
+ *  $Id: ephy-gui.c,v 1.34 2005/02/01 23:42:47 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-gui.h"
 #include "eel-gconf-extensions.h"
@@ -28,6 +26,7 @@
 #include <ctype.h>
 #include <string.h>
 #include <glib/gi18n.h>
+#include <gdk/gdkx.h>
 #include <libgnome/gnome-help.h>
 #include <gtk/gtktreemodel.h>
 #include <gtk/gtkmessagedialog.h>
@@ -36,9 +35,6 @@
 #include <gtk/gtklabel.h>
 #include <gtk/gtkstock.h>
 #include <gtk/gtkmain.h>
-#include <gtk/gtkwindow.h>
-#include <gtk/gtkversion.h>
-#include <gtk/gtkicontheme.h>
 #include <gtk/gtktreeselection.h>
 
 void
@@ -118,14 +114,11 @@ ephy_gui_menu_position_under_widget (GtkMenu   *menu,
 {
 	GtkWidget *w = GTK_WIDGET (user_data);
 	GtkRequisition requisition;
-	gboolean rtl;
-
-	rtl = (gtk_widget_get_direction (w) == GTK_TEXT_DIR_RTL);
 
 	gdk_window_get_origin (w->window, x, y);
 	gtk_widget_size_request (GTK_WIDGET (menu), &requisition);
 
-	if (rtl)
+	if (gtk_widget_get_direction (w) == GTK_TEXT_DIR_RTL)
 	{
 		*x += w->allocation.x + w->allocation.width - requisition.width;
 	}
@@ -139,13 +132,66 @@ ephy_gui_menu_position_under_widget (GtkMenu   *menu,
 	ephy_gui_sanitise_popup_position (menu, w, x, y);
 }
 
-gboolean
-ephy_gui_confirm_overwrite_file (GtkWidget *parent, const char *filename)
+void
+ephy_gui_menu_position_on_panel (GtkMenu *menu,
+				 gint      *x,
+				 gint      *y,
+				 gboolean  *push_in,
+				 gpointer  user_data)
 {
-	char *primary_text, *question, *converted;
-	GtkWidget *dialog, *hbox, *label;
-	GtkWidget *image;
-	gboolean res;
+	GtkWidget *widget = GTK_WIDGET (user_data);
+	GtkRequisition requisition;
+	GdkScreen *screen;
+
+	screen = gtk_widget_get_screen (widget);
+
+	gdk_window_get_origin (widget->window, x, y);
+	gtk_widget_size_request (GTK_WIDGET (menu), &requisition);
+
+	if (GTK_WIDGET_NO_WINDOW (widget))
+	{
+		*x += widget->allocation.x;
+		*y += widget->allocation.y;
+	}
+
+	/* FIXME: Adapt to vertical panels, but egg_tray_icon_get_orientation doesn't seem to work */
+	if (*y > gdk_screen_get_height (screen) / 2)
+	{
+		*y -= requisition.height;
+	}
+	else
+	{
+		*y += widget->allocation.height;
+	}
+
+	*push_in = FALSE;
+
+	ephy_gui_sanitise_popup_position (menu, widget, x, y);
+}
+
+GtkWindowGroup *
+ephy_gui_ensure_window_group (GtkWindow *window)
+{
+	GtkWindowGroup *group;
+
+	group = window->group;
+	if (group == NULL)
+	{
+		group = gtk_window_group_new ();
+		gtk_window_group_add_window (group, window);
+		g_object_unref (group);
+	}
+
+	return group;
+}
+
+gboolean
+ephy_gui_confirm_overwrite_file (GtkWidget *parent,
+				 const char *filename)
+{
+	GtkWidget *dialog;
+	char *display_name;
+	gboolean retval;
 
 	if (filename == NULL) return FALSE;
 
@@ -154,51 +200,41 @@ ephy_gui_confirm_overwrite_file (GtkWidget *parent, const char *filename)
 		return TRUE;
 	}
 
-	converted = g_filename_to_utf8 (filename, -1, NULL, NULL, NULL);
-	if (converted == NULL) return FALSE;
+	display_name = g_filename_display_basename (filename);
 
-	primary_text = g_strdup_printf (_("A file %s already exists."), 
-	                                converted);
+	dialog = gtk_message_dialog_new
+		(parent ? GTK_WINDOW (parent) : NULL,
+		 GTK_DIALOG_DESTROY_WITH_PARENT,
+		 GTK_MESSAGE_QUESTION,
+		 GTK_BUTTONS_CANCEL,
+		 _("Overwrite \"%s\"?"), display_name);
 
-	question = g_strdup_printf ("<b><big>%s</big></b>\n\n%s", primary_text,
-	                            _("If you choose to overwrite this file, "
-				      "the contents will be lost."));
+	gtk_message_dialog_format_secondary_text
+		(GTK_MESSAGE_DIALOG (dialog),
+		 _("A file with this name already exists. If you choose to "
+		   "overwrite this file, the contents will be lost."));
 
-	dialog = gtk_dialog_new_with_buttons (_("Overwrite File"),
-                                        parent ? GTK_WINDOW (parent) : NULL,
-                                        GTK_DIALOG_MODAL | GTK_DIALOG_NO_SEPARATOR,
-                                        GTK_STOCK_CANCEL,
-					GTK_RESPONSE_CANCEL,
-					_("_Overwrite"), GTK_RESPONSE_ACCEPT,
-					NULL);
-	ephy_gui_set_default_window_icon (GTK_WINDOW (dialog));
+	gtk_dialog_add_button (GTK_DIALOG (dialog),
+			       _("_Overwrite"), GTK_RESPONSE_ACCEPT);
 
-	hbox = gtk_hbox_new (FALSE, 6);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox, TRUE, TRUE, 12);
-	image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_WARNING, GTK_ICON_SIZE_DIALOG);
-	gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
-	gtk_box_pack_start (GTK_BOX (hbox), image, TRUE, TRUE, 0);
+	gtk_window_set_title (GTK_WINDOW (dialog), _("Overwrite File?"));
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
 
-	label = gtk_label_new (NULL);
-	gtk_label_set_selectable (GTK_LABEL (label), TRUE);
-	gtk_label_set_markup (GTK_LABEL (label), question);
-	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-	gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
-	gtk_widget_show_all (hbox);
-
-	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-	gtk_window_set_skip_taskbar_hint (GTK_WINDOW (dialog), TRUE);
-	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (dialog)), 6);
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CANCEL);
-        res = (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT) ? TRUE : FALSE;
+
+	if (parent != NULL)
+	{
+		gtk_window_group_add_window (ephy_gui_ensure_window_group (GTK_WINDOW (parent)),
+					     GTK_WINDOW (dialog));
+	}
+
+	retval = (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT);
 
 	gtk_widget_destroy (dialog);
 
-	g_free (primary_text);
-	g_free (question);
-	g_free (converted);
+	g_free (display_name);
 
-	return res;
+	return retval;
 }
 
 void
@@ -310,40 +346,14 @@ ephy_gui_is_middle_click (void)
 }
 
 void
-ephy_gui_set_default_window_icon (GtkWindow *window)
+ephy_gui_window_update_user_time (GtkWidget *window,
+				  guint32 user_time)
 {
-#if GTK_CHECK_VERSION (2, 5, 4)
-	gtk_window_set_icon_name (window, "web-browser");
-#else
-	const char *icon_path;
-	GdkPixbuf *icon = NULL;
-	GtkIconTheme *icon_theme;
-	GtkIconInfo *icon_info;
-
-	icon_theme = gtk_icon_theme_get_default ();
-	icon_info = gtk_icon_theme_lookup_icon (icon_theme, "web-browser", -1, 0);
-
-	if (icon_info != NULL)
+	if (user_time != 0)
 	{
-		icon_path = gtk_icon_info_get_filename (icon_info);
-
-		if (icon_path != NULL)
-		{
-			icon = gdk_pixbuf_new_from_file (icon_path, NULL);
-		}
-
-		gtk_icon_info_free (icon_info);
-	}
-	else
-	{
-		g_warning ("Web browser gnome icon not found");
+		gtk_widget_realize (window);
+		gdk_x11_window_set_user_time (window->window,
+					      user_time);
 	}
 
-	gtk_window_set_icon (GTK_WINDOW (window), icon);
-
-	if (icon != NULL)
-	{
-		g_object_unref (icon);
-	}
-#endif
 }
