@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-gui.h,v 1.12 2004/09/14 20:28:42 marco Exp $
+ *  $Id: ephy-gui.h,v 1.16 2005/02/01 23:42:47 chpe Exp $
  */
 
 #ifndef EPHY_GUI_H
@@ -30,6 +30,11 @@
 
 G_BEGIN_DECLS
 
+void		ephy_gui_sanitise_popup_position	 (GtkMenu *menu,
+							  GtkWidget *parent_widget,
+							  gint *x,
+							  gint *y);
+
 void		ephy_gui_menu_position_tree_selection    (GtkMenu   *menu,
 							  gint      *x,
 							  gint      *y,
@@ -42,6 +47,14 @@ void		ephy_gui_menu_position_under_widget	 (GtkMenu   *menu,
 							  gboolean  *push_in,
 							  gpointer  user_data);
 
+void		ephy_gui_menu_position_on_panel		 (GtkMenu *menu,
+							  gint      *x,
+							  gint      *y,
+							  gboolean  *push_in,
+							  gpointer  user_data);
+
+GtkWindowGroup *ephy_gui_ensure_window_group		 (GtkWindow *window);
+
 gboolean	ephy_gui_is_middle_click		 (void);
 
 gboolean	ephy_gui_select_row_by_key		 (GtkTreeView *treeview,
@@ -55,6 +68,9 @@ void		ephy_gui_help				 (GtkWindow *parent,
 							  const char *file_name,
 							  const char *link_id);
 
+void		ephy_gui_window_update_user_time	 (GtkWidget *window,
+							  guint32 user_time);
+
 G_END_DECLS
 
 #endif
