@@ -51,7 +51,7 @@ G_BEGIN_DECLS
 #endif /* !G_ENABLE_DEBUG */
 
 
-/* BOOLEAN:ENUM,STRING,STRING,STRING (./ephy-marshal.list:1) */
+/* BOOLEAN:ENUM,STRING,STRING,STRING (../../lib/ephy-marshal.list:1) */
 extern void ephy_marshal_BOOLEAN__ENUM_STRING_STRING_STRING (GClosure     *closure,
                                                              GValue       *return_value,
                                                              guint         n_param_values,
@@ -102,7 +102,7 @@ ephy_marshal_BOOLEAN__ENUM_STRING_STRING_STRING (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT (./ephy-marshal.list:2) */
+/* BOOLEAN:OBJECT (../../lib/ephy-marshal.list:2) */
 extern void ephy_marshal_BOOLEAN__OBJECT (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -147,7 +147,7 @@ ephy_marshal_BOOLEAN__OBJECT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:STRING,STRING (./ephy-marshal.list:3) */
+/* BOOLEAN:STRING,STRING (../../lib/ephy-marshal.list:3) */
 extern void ephy_marshal_BOOLEAN__STRING_STRING (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
@@ -194,7 +194,7 @@ ephy_marshal_BOOLEAN__STRING_STRING (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:VOID (./ephy-marshal.list:4) */
+/* BOOLEAN:VOID (../../lib/ephy-marshal.list:4) */
 extern void ephy_marshal_BOOLEAN__VOID (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
@@ -237,31 +237,32 @@ ephy_marshal_BOOLEAN__VOID (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* OBJECT:FLAGS (./ephy-marshal.list:5) */
-extern void ephy_marshal_OBJECT__FLAGS (GClosure     *closure,
-                                        GValue       *return_value,
-                                        guint         n_param_values,
-                                        const GValue *param_values,
-                                        gpointer      invocation_hint,
-                                        gpointer      marshal_data);
+/* OBJECT:OBJECT,FLAGS (../../lib/ephy-marshal.list:5) */
+extern void ephy_marshal_OBJECT__OBJECT_FLAGS (GClosure     *closure,
+                                               GValue       *return_value,
+                                               guint         n_param_values,
+                                               const GValue *param_values,
+                                               gpointer      invocation_hint,
+                                               gpointer      marshal_data);
 void
-ephy_marshal_OBJECT__FLAGS (GClosure     *closure,
-                            GValue       *return_value,
-                            guint         n_param_values,
-                            const GValue *param_values,
-                            gpointer      invocation_hint,
-                            gpointer      marshal_data)
+ephy_marshal_OBJECT__OBJECT_FLAGS (GClosure     *closure,
+                                   GValue       *return_value,
+                                   guint         n_param_values,
+                                   const GValue *param_values,
+                                   gpointer      invocation_hint,
+                                   gpointer      marshal_data)
 {
-  typedef GObject* (*GMarshalFunc_OBJECT__FLAGS) (gpointer     data1,
-                                                  guint        arg_1,
-                                                  gpointer     data2);
-  register GMarshalFunc_OBJECT__FLAGS callback;
+  typedef GObject* (*GMarshalFunc_OBJECT__OBJECT_FLAGS) (gpointer     data1,
+                                                         gpointer     arg_1,
+                                                         guint        arg_2,
+                                                         gpointer     data2);
+  register GMarshalFunc_OBJECT__OBJECT_FLAGS callback;
   register GCClosure *cc = (GCClosure*) closure;
   register gpointer data1, data2;
   GObject* v_return;
 
   g_return_if_fail (return_value != NULL);
-  g_return_if_fail (n_param_values == 2);
+  g_return_if_fail (n_param_values == 3);
 
   if (G_CCLOSURE_SWAP_DATA (closure))
     {
@@ -273,16 +274,17 @@ ephy_marshal_OBJECT__FLAGS (GClosure     *closure,
       data1 = g_value_peek_pointer (param_values + 0);
       data2 = closure->data;
     }
-  callback = (GMarshalFunc_OBJECT__FLAGS) (marshal_data ? marshal_data : cc->callback);
+  callback = (GMarshalFunc_OBJECT__OBJECT_FLAGS) (marshal_data ? marshal_data : cc->callback);
 
   v_return = callback (data1,
-                       g_marshal_value_peek_flags (param_values + 1),
+                       g_marshal_value_peek_object (param_values + 1),
+                       g_marshal_value_peek_flags (param_values + 2),
                        data2);
 
   g_value_take_object (return_value, v_return);
 }
 
-/* OBJECT:STRING,OBJECT,FLAGS (./ephy-marshal.list:6) */
+/* OBJECT:STRING,OBJECT,FLAGS (../../lib/ephy-marshal.list:6) */
 extern void ephy_marshal_OBJECT__STRING_OBJECT_FLAGS (GClosure     *closure,
                                                       GValue       *return_value,
                                                       guint         n_param_values,
@@ -331,7 +333,7 @@ ephy_marshal_OBJECT__STRING_OBJECT_FLAGS (GClosure     *closure,
   g_value_take_object (return_value, v_return);
 }
 
-/* STRING:VOID (./ephy-marshal.list:7) */
+/* STRING:VOID (../../lib/ephy-marshal.list:7) */
 extern void ephy_marshal_STRING__VOID (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
@@ -374,10 +376,10 @@ ephy_marshal_STRING__VOID (GClosure     *closure,
   g_value_take_string (return_value, v_return);
 }
 
-/* VOID:ENUM (./ephy-marshal.list:8) */
+/* VOID:ENUM (../../lib/ephy-marshal.list:8) */
 #define ephy_marshal_VOID__ENUM	g_cclosure_marshal_VOID__ENUM
 
-/* VOID:POINTER,BOOLEAN (./ephy-marshal.list:9) */
+/* VOID:POINTER,BOOLEAN (../../lib/ephy-marshal.list:9) */
 extern void ephy_marshal_VOID__POINTER_BOOLEAN (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -420,7 +422,7 @@ ephy_marshal_VOID__POINTER_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER,POINTER (./ephy-marshal.list:10) */
+/* VOID:POINTER,POINTER (../../lib/ephy-marshal.list:10) */
 extern void ephy_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -463,7 +465,7 @@ ephy_marshal_VOID__POINTER_POINTER (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,FLAGS (./ephy-marshal.list:11) */
+/* VOID:STRING,FLAGS (../../lib/ephy-marshal.list:11) */
 extern void ephy_marshal_VOID__STRING_FLAGS (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -506,7 +508,7 @@ ephy_marshal_VOID__STRING_FLAGS (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,INT (./ephy-marshal.list:12) */
+/* VOID:STRING,INT (../../lib/ephy-marshal.list:12) */
 extern void ephy_marshal_VOID__STRING_INT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -549,7 +551,7 @@ ephy_marshal_VOID__STRING_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,STRING (./ephy-marshal.list:13) */
+/* VOID:STRING,STRING (../../lib/ephy-marshal.list:13) */
 extern void ephy_marshal_VOID__STRING_STRING (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
