@@ -6,13 +6,13 @@
 
 G_BEGIN_DECLS
 
-/* INT:STRING (../../lib/ephy-marshal.list:1) */
-extern void ephy_marshal_INT__STRING (GClosure     *closure,
-                                      GValue       *return_value,
-                                      guint         n_param_values,
-                                      const GValue *param_values,
-                                      gpointer      invocation_hint,
-                                      gpointer      marshal_data);
+/* BOOLEAN:ENUM,STRING,STRING,STRING (../../lib/ephy-marshal.list:1) */
+extern void ephy_marshal_BOOLEAN__ENUM_STRING_STRING_STRING (GClosure     *closure,
+                                                             GValue       *return_value,
+                                                             guint         n_param_values,
+                                                             const GValue *param_values,
+                                                             gpointer      invocation_hint,
+                                                             gpointer      marshal_data);
 
 /* BOOLEAN:OBJECT (../../lib/ephy-marshal.list:2) */
 extern void ephy_marshal_BOOLEAN__OBJECT (GClosure     *closure,
@@ -38,31 +38,34 @@ extern void ephy_marshal_BOOLEAN__VOID (GClosure     *closure,
                                         gpointer      invocation_hint,
                                         gpointer      marshal_data);
 
-/* VOID:ENUM,INT,BOOLEAN (../../lib/ephy-marshal.list:5) */
-extern void ephy_marshal_VOID__ENUM_INT_BOOLEAN (GClosure     *closure,
-                                                 GValue       *return_value,
-                                                 guint         n_param_values,
-                                                 const GValue *param_values,
-                                                 gpointer      invocation_hint,
-                                                 gpointer      marshal_data);
+/* OBJECT:OBJECT,FLAGS (../../lib/ephy-marshal.list:5) */
+extern void ephy_marshal_OBJECT__OBJECT_FLAGS (GClosure     *closure,
+                                               GValue       *return_value,
+                                               guint         n_param_values,
+                                               const GValue *param_values,
+                                               gpointer      invocation_hint,
+                                               gpointer      marshal_data);
 
-/* VOID:INT,INT (../../lib/ephy-marshal.list:6) */
-extern void ephy_marshal_VOID__INT_INT (GClosure     *closure,
-                                        GValue       *return_value,
-                                        guint         n_param_values,
-                                        const GValue *param_values,
-                                        gpointer      invocation_hint,
-                                        gpointer      marshal_data);
+/* OBJECT:STRING,OBJECT,FLAGS (../../lib/ephy-marshal.list:6) */
+extern void ephy_marshal_OBJECT__STRING_OBJECT_FLAGS (GClosure     *closure,
+                                                      GValue       *return_value,
+                                                      guint         n_param_values,
+                                                      const GValue *param_values,
+                                                      gpointer      invocation_hint,
+                                                      gpointer      marshal_data);
 
-/* VOID:POINTER,INT (../../lib/ephy-marshal.list:7) */
-extern void ephy_marshal_VOID__POINTER_INT (GClosure     *closure,
-                                            GValue       *return_value,
-                                            guint         n_param_values,
-                                            const GValue *param_values,
-                                            gpointer      invocation_hint,
-                                            gpointer      marshal_data);
+/* STRING:VOID (../../lib/ephy-marshal.list:7) */
+extern void ephy_marshal_STRING__VOID (GClosure     *closure,
+                                       GValue       *return_value,
+                                       guint         n_param_values,
+                                       const GValue *param_values,
+                                       gpointer      invocation_hint,
+                                       gpointer      marshal_data);
 
-/* VOID:POINTER,BOOLEAN (../../lib/ephy-marshal.list:8) */
+/* VOID:ENUM (../../lib/ephy-marshal.list:8) */
+#define ephy_marshal_VOID__ENUM	g_cclosure_marshal_VOID__ENUM
+
+/* VOID:POINTER,BOOLEAN (../../lib/ephy-marshal.list:9) */
 extern void ephy_marshal_VOID__POINTER_BOOLEAN (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -70,7 +73,7 @@ extern void ephy_marshal_VOID__POINTER_BOOLEAN (GClosure     *closure,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);
 
-/* VOID:POINTER,POINTER (../../lib/ephy-marshal.list:9) */
+/* VOID:POINTER,POINTER (../../lib/ephy-marshal.list:10) */
 extern void ephy_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -78,7 +81,15 @@ extern void ephy_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);
 
-/* VOID:STRING,INT (../../lib/ephy-marshal.list:10) */
+/* VOID:STRING,FLAGS (../../lib/ephy-marshal.list:11) */
+extern void ephy_marshal_VOID__STRING_FLAGS (GClosure     *closure,
+                                             GValue       *return_value,
+                                             guint         n_param_values,
+                                             const GValue *param_values,
+                                             gpointer      invocation_hint,
+                                             gpointer      marshal_data);
+
+/* VOID:STRING,INT (../../lib/ephy-marshal.list:12) */
 extern void ephy_marshal_VOID__STRING_INT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -86,15 +97,7 @@ extern void ephy_marshal_VOID__STRING_INT (GClosure     *closure,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);
 
-/* VOID:STRING,INT,INT (../../lib/ephy-marshal.list:11) */
-extern void ephy_marshal_VOID__STRING_INT_INT (GClosure     *closure,
-                                               GValue       *return_value,
-                                               guint         n_param_values,
-                                               const GValue *param_values,
-                                               gpointer      invocation_hint,
-                                               gpointer      marshal_data);
-
-/* VOID:STRING,STRING (../../lib/ephy-marshal.list:12) */
+/* VOID:STRING,STRING (../../lib/ephy-marshal.list:13) */
 extern void ephy_marshal_VOID__STRING_STRING (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
@@ -102,14 +105,6 @@ extern void ephy_marshal_VOID__STRING_STRING (GClosure     *closure,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
 
-/* VOID:STRING,BOOLEAN (../../lib/ephy-marshal.list:13) */
-extern void ephy_marshal_VOID__STRING_BOOLEAN (GClosure     *closure,
-                                               GValue       *return_value,
-                                               guint         n_param_values,
-                                               const GValue *param_values,
-                                               gpointer      invocation_hint,
-                                               gpointer      marshal_data);
-
 G_END_DECLS
 
 #endif /* __ephy_marshal_MARSHAL_H__ */
