@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: ephy-bookmarks-editor.c,v 1.167 2005/01/24 14:45:53 chpe Exp $
+ * $Id: ephy-bookmarks-editor.c,v 1.170 2005/01/28 22:25:02 chpe Exp $
  */
 
 #include "config.h"
@@ -625,14 +625,16 @@ import_bookmarks (EphyBookmarksEditor *editor,
 		basename = g_filename_display_basename (filename);
 		dialog = gtk_message_dialog_new (GTK_WINDOW (editor),
 						 GTK_DIALOG_MODAL,
-						 GTK_MESSAGE_WARNING,
+						 GTK_MESSAGE_ERROR,
 						 GTK_BUTTONS_OK,
 						 _("Import failed"));
 
 		gtk_window_set_title (GTK_WINDOW (dialog), _("Import Failed"));
 		gtk_message_dialog_format_secondary_text
 			(GTK_MESSAGE_DIALOG (dialog),
-			 _("The bookmarks from \"%s\" were not imported."),
+			 _("The bookmarks from \"%s\" could not be imported "
+			   "because the file is corrupted or of an "
+			   "unsupported type."),
 			 basename);
 
 		gtk_window_group_add_window (GTK_WINDOW (editor)->group,
@@ -1161,7 +1163,7 @@ ephy_bookmarks_editor_update_menu (EphyBookmarksEditor *editor)
 	GtkWidget *focus_widget;
 	int num_bmk_selected;
 
-	LOG ("Update menu sensitivity")
+	LOG ("Update menu sensitivity");
 
 	bmk_focus = ephy_node_view_is_target
 		(EPHY_NODE_VIEW (editor->priv->bm_view));
@@ -1545,7 +1547,7 @@ provide_favicon (EphyNode *node, GValue *value, gpointer user_data)
 	icon_location = ephy_node_get_property_string
 		(node, EPHY_NODE_BMK_PROP_ICON);
 
-	LOG ("Get favicon for %s", icon_location ? icon_location : "None")
+	LOG ("Get favicon for %s", icon_location ? icon_location : "None");
 
 	if (icon_location)
 	{
