@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-session.c,v 1.31 2004/11/13 21:39:18 chpe Exp $
+ *  $Id: ephy-session.c,v 1.36 2005/02/01 23:42:47 chpe Exp $
  */
 
 #include "config.h"
@@ -29,10 +29,10 @@
 #include "ephy-shell.h"
 #include "ephy-history-window.h"
 #include "ephy-bookmarks-editor.h"
-#include "ephy-string.h"
 #include "ephy-file-helpers.h"
 #include "eel-gconf-extensions.h"
 #include "ephy-prefs.h"
+#include "ephy-gui.h"
 #include "ephy-debug.h"
 
 #include <glib/gi18n.h>
@@ -52,7 +52,7 @@
 
 #define EPHY_SESSION_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_SESSION, EphySessionPrivate))
 
-struct EphySessionPrivate
+struct _EphySessionPrivate
 {
 	GList *windows;
 	GList *tool_windows;
@@ -191,7 +191,7 @@ window_focus_in_event_cb (EphyWindow *window,
 			  GdkEventFocus *event,
 			  EphySession *session)
 {
-	LOG ("focus-in-event for window %p", window)
+	LOG ("focus-in-event for window %p", window);
 
 	g_return_val_if_fail (g_list_find (session->priv->windows, window) != NULL, FALSE);
 
@@ -212,7 +212,7 @@ impl_attach_window (EphyExtension *extension,
 	EphySession *session = EPHY_SESSION (extension);
 	GtkWidget *notebook;
 
-	LOG ("impl_attach_window")
+	LOG ("impl_attach_window");
 
 	session->priv->windows = g_list_append (session->priv->windows, window);
 	ephy_session_save (session, SESSION_CRASHED);
@@ -235,7 +235,7 @@ impl_detach_window (EphyExtension *extension,
 {
 	EphySession *session = EPHY_SESSION (extension);
 
-	LOG ("impl_detach_window")
+	LOG ("impl_detach_window");
 
 	session->priv->windows = g_list_remove (session->priv->windows, window);
 	ephy_session_save (session, SESSION_CRASHED);
@@ -267,7 +267,7 @@ ephy_session_init (EphySession *session)
 {
 	session->priv = EPHY_SESSION_GET_PRIVATE (session);
 
-	LOG ("EphySession initialising")
+	LOG ("EphySession initialising");
 
 	ensure_session_directory ();
 }
@@ -277,7 +277,7 @@ ephy_session_dispose (GObject *object)
 {
 	EphySession *session = EPHY_SESSION(object);
 
-	LOG ("EphySession disposing")
+	LOG ("EphySession disposing");
 
 	session_delete (session, SESSION_CRASHED);
 
@@ -289,7 +289,7 @@ ephy_session_finalize (GObject *object)
 {
 	EphySession *session = EPHY_SESSION (object);
 
-	LOG ("EphySession finalising")
+	LOG ("EphySession finalising");
 
 	/* FIXME: those should be NULL already!? */
 	g_list_free (session->priv->windows);
@@ -358,7 +358,8 @@ ephy_session_class_init (EphySessionClass *class)
 }
 
 static gboolean
-offer_to_resume (EphySession *session)
+offer_to_resume (EphySession *session,
+		 guint32 user_time)
 {
 	GtkWidget *dialog;
 	int response;
@@ -386,6 +387,9 @@ offer_to_resume (EphySession *session)
 
 	session->priv->resume_dialog = dialog;
 
+	ephy_gui_window_update_user_time (session->priv->resume_dialog,
+					  user_time);
+
 	response = gtk_dialog_run (GTK_DIALOG (dialog));
 
 	gtk_widget_destroy (dialog);
@@ -398,6 +402,7 @@ offer_to_resume (EphySession *session)
 /**
  * ephy_session_autoresume:
  * @session: a #EphySession
+ * @user_time: a timestamp, or 0
  *
  * Resume a crashed session when necessary (interactive)
  *
@@ -406,28 +411,33 @@ offer_to_resume (EphySession *session)
  * has been re-presented to the user.
  **/
 gboolean
-ephy_session_autoresume (EphySession *session)
+ephy_session_autoresume (EphySession *session,
+			 guint32 user_time)
 {
+	EphySessionPrivate *priv = session->priv;
 	char *saved_session;
 	gboolean retval = FALSE;
 
-	LOG ("ephy_session_autoresume")
+	LOG ("ephy_session_autoresume");
 
-	if (session->priv->windows != NULL) return FALSE;
+	if (priv->windows != NULL || priv->tool_windows != NULL) return FALSE;
 
-	if (session->priv->resume_dialog)
+	if (priv->resume_dialog)
 	{
-		gtk_window_present (GTK_WINDOW (session->priv->resume_dialog));
+		ephy_gui_window_update_user_time (session->priv->resume_dialog,
+						  user_time);
+		gtk_window_present (GTK_WINDOW (priv->resume_dialog));
 		return TRUE;
 	}
 
 	saved_session = get_session_filename (SESSION_CRASHED);
 
 	if (g_file_test (saved_session, G_FILE_TEST_EXISTS)
-	    && offer_to_resume (session))
+	    && offer_to_resume (session, user_time))
 	{
 		session->priv->dont_save = TRUE;
-		retval = ephy_session_load (session, saved_session);
+		retval = ephy_session_load (session, saved_session,
+					    user_time);
 		session->priv->dont_save = FALSE;
 		ephy_session_save (session, SESSION_CRASHED);
 	}
@@ -442,7 +452,7 @@ ephy_session_close (EphySession *session)
 {
 	GList *windows;
 
-	LOG ("ephy_session_close")
+	LOG ("ephy_session_close");
 
 	/* we have to ref the shell or else we may get finalised between
 	 * destroying the windows and destroying the tool windows
@@ -588,7 +598,7 @@ ephy_session_save (EphySession *session,
 		return TRUE;
 	}
 
-	LOG ("ephy_sesion_save %s", filename)
+	LOG ("ephy_sesion_save %s", filename);
 
 	if (session->priv->windows == NULL && session->priv->tool_windows == NULL)
 	{
@@ -739,6 +749,7 @@ restore_geometry (GtkWindow *window,
  * ephy_session_load:
  * @session: a #EphySession
  * @filename: the path of the source file
+ * @user_time: a timestamp, or 0
  *
  * Load a session from disk, restoring the windows and their state
  *
@@ -746,14 +757,15 @@ restore_geometry (GtkWindow *window,
  **/
 gboolean
 ephy_session_load (EphySession *session,
-		   const char *filename)
+		   const char *filename,
+		   guint32 user_time)
 {
 	xmlDocPtr doc;
         xmlNodePtr child;
 	GtkWidget *widget = NULL;
 	char *save_to;
 
-	LOG ("ephy_sesion_load %s", filename)
+	LOG ("ephy_sesion_load %s", filename);
 
 	save_to = get_session_filename (filename);
 
@@ -777,6 +789,9 @@ ephy_session_load (EphySession *session,
 			widget = GTK_WIDGET (ephy_window_new ());
 			restore_geometry (GTK_WINDOW (widget), child);
 			parse_embed (child->children, EPHY_WINDOW (widget));
+
+			ephy_gui_window_update_user_time (widget, user_time);
+
 			gtk_window_present (GTK_WINDOW (widget));
 		}
 		else if (xmlStrEqual (child->name, (const xmlChar *) "toolwindow"))
@@ -801,6 +816,9 @@ ephy_session_load (EphySession *session,
 			}
 
 			restore_geometry (GTK_WINDOW (widget), child);
+
+			ephy_gui_window_update_user_time (widget, user_time);
+
 			gtk_window_present (GTK_WINDOW (widget));
 		}
 
@@ -838,7 +856,7 @@ void
 ephy_session_add_window (EphySession *session,
 			 GtkWindow *window)
 {
-	LOG ("ephy_session_add_window %p", window)
+	LOG ("ephy_session_add_window %p", window);
 
 	session->priv->tool_windows =
 		g_list_append (session->priv->tool_windows, window);
@@ -858,7 +876,7 @@ void
 ephy_session_remove_window (EphySession *session,
 			    GtkWindow *window)
 {
-	LOG ("ephy_session_remove_window %p", window)
+	LOG ("ephy_session_remove_window %p", window);
 
 	session->priv->tool_windows =
 		g_list_remove (session->priv->tool_windows, window);
