@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-shell.c,v 1.111 2005/01/15 16:47:39 crispin Exp $
+ *  $Id: ephy-shell.c,v 1.118 2005/02/02 19:32:47 chpe Exp $
  */
 
 #include "config.h"
@@ -24,6 +24,7 @@
 #include "ephy-shell.h"
 #include "ephy-type-builtins.h"
 #include "ephy-embed-shell.h"
+#include "ephy-embed-single.h"
 #include "eel-gconf-extensions.h"
 #include "ephy-prefs.h"
 #include "ephy-file-helpers.h"
@@ -44,6 +45,8 @@
 #include "ephy-toolbar.h"
 #include "ephy-automation.h"
 #include "print-dialog.h"
+#include "ephy-prefs.h"
+#include "ephy-gui.h"
 
 #ifdef ENABLE_DBUS
 #include "ephy-dbus.h"
@@ -80,6 +83,8 @@ struct _EphyShellPrivate
 	GObject *prefs_dialog;
 	GObject *print_setup_dialog;
 	GList *del_on_exit;
+
+	gboolean embed_single_connected;
 };
 
 EphyShell *ephy_shell = NULL;
@@ -87,6 +92,7 @@ EphyShell *ephy_shell = NULL;
 static void ephy_shell_class_init	(EphyShellClass *klass);
 static void ephy_shell_init		(EphyShell *shell);
 static void ephy_shell_finalize		(GObject *object);
+static GObject *impl_get_embed_single   (EphyEmbedShell *embed_shell);
 
 static GObjectClass *parent_class = NULL;
 
@@ -135,14 +141,115 @@ static void
 ephy_shell_class_init (EphyShellClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
+	EphyEmbedShellClass *embed_shell_class = EPHY_EMBED_SHELL_CLASS (klass);
 
 	parent_class = g_type_class_peek_parent (klass);
 
 	object_class->finalize = ephy_shell_finalize;
 
+	embed_shell_class->get_embed_single = impl_get_embed_single;
+
 	g_type_class_add_private (object_class, sizeof(EphyShellPrivate));
 }
 
+static EphyEmbed *
+ephy_shell_new_window_cb (EphyEmbedSingle *single,
+			  EphyEmbed *parent_embed,
+			  EphyEmbedChrome chromemask,
+			  EphyShell *shell)
+{
+	GtkWidget *parent = NULL;
+	EphyTab *new_tab;
+	EphyNewTabFlags flags = EPHY_NEW_TAB_DONT_SHOW_WINDOW |
+				EPHY_NEW_TAB_APPEND_LAST |
+				EPHY_NEW_TAB_IN_NEW_WINDOW |
+				EPHY_NEW_TAB_JUMP;
+
+	LOG ("ephy_shell_new_window_cb tab chrome %d", chromemask);
+
+	if (eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_JAVASCRIPT_CHROME))
+	{
+		chromemask = EPHY_EMBED_CHROME_ALL;
+	}
+
+	if (parent_embed != NULL)
+	{
+		/* this will either be a EphyWindow, or the embed itself
+		 * (in case it's about to be destroyed, which means it's already
+		 * removed from its tab)
+		 */
+		parent = gtk_widget_get_toplevel (GTK_WIDGET (parent_embed));
+	}
+
+	new_tab = ephy_shell_new_tab_full
+		(shell,
+		 EPHY_IS_WINDOW (parent) ? EPHY_WINDOW (parent) : NULL,
+		 NULL, NULL, flags, chromemask, 0);
+
+	return ephy_tab_get_embed (new_tab);
+}
+
+
+static gboolean
+ephy_shell_add_sidebar_cb (EphyEmbedSingle *embed_single,
+			   const char *url,
+			   const char *title,
+			   EphyShell *shell)
+{
+	EphySession *session;
+	EphyWindow *window;
+	GtkWidget *dialog;
+
+	session = EPHY_SESSION (ephy_shell_get_session (shell));
+	g_return_val_if_fail (EPHY_IS_SESSION (session), FALSE);
+
+	window = ephy_session_get_active_window (session);
+
+	dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+					 GTK_DIALOG_DESTROY_WITH_PARENT,
+					 GTK_MESSAGE_ERROR,
+					 GTK_BUTTONS_OK,
+					 _("Sidebar extension required"));
+
+	gtk_window_set_title (GTK_WINDOW (dialog), _("Sidebar Extension Required"));
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
+
+	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+		  _("The link you clicked needs the sidebar extension to be "
+		    "installed."));
+
+	g_signal_connect_swapped (dialog, "response", 
+				  G_CALLBACK (gtk_widget_destroy), dialog);
+
+	gtk_widget_show (dialog);
+
+	return TRUE;
+}
+
+static GObject*
+impl_get_embed_single (EphyEmbedShell *embed_shell)
+{
+	EphyShell *shell = EPHY_SHELL (embed_shell);
+	GObject *embed_single;
+
+	embed_single = EPHY_EMBED_SHELL_CLASS (parent_class)->get_embed_single (embed_shell);
+
+	if (embed_single != NULL && shell->priv->embed_single_connected == FALSE)
+	{
+		g_signal_connect_object (embed_single, "new-window",
+					 G_CALLBACK (ephy_shell_new_window_cb),
+					 shell, G_CONNECT_AFTER);
+
+		g_signal_connect_object (embed_single, "add-sidebar",
+					 G_CALLBACK (ephy_shell_add_sidebar_cb),
+					 shell, G_CONNECT_AFTER);
+
+		shell->priv->embed_single_connected = TRUE;
+	}
+	
+	return embed_single;
+}
+
 static BonoboObject *
 ephy_automation_factory_cb (BonoboGenericFactory *this_factory,
 			    const char *iid,
@@ -209,8 +316,11 @@ path_from_command_line_arg (const char *arg)
 
 static void
 open_urls (GNOME_EphyAutomation automation,
-	   const char **args, CORBA_Environment *ev,
-	   gboolean new_tab, gboolean existing_window,
+	   guint32 user_time,
+	   const char **args,
+	   CORBA_Environment *ev,
+	   gboolean new_tab,
+	   gboolean existing_window,
 	   gboolean fullscreen)
 {
 	int i;
@@ -218,9 +328,9 @@ open_urls (GNOME_EphyAutomation automation,
 	if (args == NULL)
 	{
 		/* Homepage or resume */
-		GNOME_EphyAutomation_loadurl
+		GNOME_EphyAutomation_loadUrlWithStartupId
 			(automation, "", fullscreen,
-			 existing_window, new_tab, ev);
+			 existing_window, new_tab, user_time, ev);
 	}
 	else
 	{
@@ -230,9 +340,9 @@ open_urls (GNOME_EphyAutomation automation,
 
 			path = path_from_command_line_arg (args[i]);
 
-			GNOME_EphyAutomation_loadurl
+			GNOME_EphyAutomation_loadUrlWithStartupId
 				(automation, path, fullscreen,
-				 existing_window, new_tab, ev);
+				 existing_window, new_tab, user_time, ev);
 
 			g_free (path);
 		}
@@ -253,7 +363,7 @@ save_yourself_cb (GnomeClient *client,
 	EphySession *session;
 	char *tmp, *save_to;
 
-	LOG ("save_yourself_cb")
+	LOG ("save_yourself_cb");
 
 	tmp = g_build_filename (ephy_dot_dir (),
 				"session_gnome-XXXXXX",
@@ -285,7 +395,7 @@ die_cb (GnomeClient* client,
 {
 	EphySession *session;
 
-	LOG ("die_cb")
+	LOG ("die_cb");
 
 	session = EPHY_SESSION (ephy_shell_get_session (shell));
 	ephy_session_close (session);
@@ -311,6 +421,7 @@ gnome_session_init (EphyShell *shell)
 gboolean
 ephy_shell_startup (EphyShell *shell,
 		    EphyShellStartupFlags flags,
+		    guint32 user_time,
 		    const char **args,
 		    const char *string_arg,
 		    GError **error)
@@ -366,13 +477,13 @@ ephy_shell_startup (EphyShell *shell,
 		}
 		else if (flags & EPHY_SHELL_STARTUP_BOOKMARKS_EDITOR)
 		{
-			GNOME_EphyAutomation_openBookmarksEditor
-				(automation, &ev);
+			GNOME_EphyAutomation_openBookmarksEditorWithStartupId
+				(automation, user_time, &ev);
 		}
 		else if (flags & EPHY_SHELL_STARTUP_SESSION)
 		{
-			GNOME_EphyAutomation_loadSession
-				(automation, string_arg, &ev);
+			GNOME_EphyAutomation_loadSessionWithStartupId
+				(automation, string_arg, user_time, &ev);
 		}
 		else if (flags & EPHY_SHELL_STARTUP_IMPORT_BOOKMARKS)
 		{
@@ -386,7 +497,7 @@ ephy_shell_startup (EphyShell *shell,
 		}
 		else
 		{
-			open_urls (automation, args, &ev,
+			open_urls (automation, user_time, args, &ev,
 				   flags & EPHY_SHELL_STARTUP_TABS,
 				   flags & EPHY_SHELL_STARTUP_EXISTING_WINDOW,
 				   flags & EPHY_SHELL_STARTUP_FULLSCREEN);
@@ -414,37 +525,38 @@ ephy_shell_finalize (GObject *object)
 	g_assert (ephy_shell == NULL);
 
 	/* this will unload the extensions */
-	LOG ("Unref extension manager")
+	LOG ("Unref extension manager");
 	if (shell->priv->extensions_manager)
 	{
 		g_object_unref (shell->priv->extensions_manager);
 	}
 
 #ifdef ENABLE_DBUS
-	LOG ("Shutting down DBUS service")
+	LOG ("Shutting down DBUS service");
 	if (shell->priv->dbus_service)
 	{
 		g_object_unref (shell->priv->dbus_service);
 	}
 #endif
 
-	LOG ("Unref session manager")
+	LOG ("Unref session manager");
 	if (shell->priv->session)
 	{
 		g_object_unref (shell->priv->session);
 	}
 
-	LOG ("Unref toolbars model")
+	LOG ("Unref toolbars model");
 	if (shell->priv->toolbars_model)
 	if (shell->priv->toolbar_style_notifier_id != 0)
 	{
 		eel_gconf_notification_remove (shell->priv->toolbar_style_notifier_id);
 	}
+	if (shell->priv->toolbars_model)
 	{
 		g_object_unref (shell->priv->toolbars_model);
 	}
 
-	LOG ("Unref fullscreen toolbars model")
+	LOG ("Unref fullscreen toolbars model");
 	if (shell->priv->fs_toolbars_model)
 	{
 		g_object_unref (shell->priv->fs_toolbars_model);
@@ -462,25 +574,25 @@ ephy_shell_finalize (GObject *object)
 		gtk_widget_destroy (GTK_WIDGET (shell->priv->history_window));
 	}
 
-	LOG ("Unref PDM Dialog")
+	LOG ("Unref PDM Dialog");
 	if (shell->priv->pdm_dialog)
 	{
 		g_object_unref (shell->priv->pdm_dialog);
 	}
 
-	LOG ("Unref prefs dialog")
+	LOG ("Unref prefs dialog");
 	if (shell->priv->prefs_dialog)
 	{
 		g_object_unref (shell->priv->prefs_dialog);
 	}
 
-	LOG ("Unref print setup dialog")
+	LOG ("Unref print setup dialog");
 	if (shell->priv->print_setup_dialog)
 	{
 		g_object_unref (shell->priv->print_setup_dialog);
 	}
 
-	LOG ("Unref bookmarks")
+	LOG ("Unref bookmarks");
 	if (shell->priv->bookmarks)
 	{
 		g_object_unref (shell->priv->bookmarks);
@@ -496,7 +608,7 @@ ephy_shell_finalize (GObject *object)
 		bonobo_object_unref (shell->priv->automation_factory);
 	}
 
-	LOG ("Ephy shell finalized")
+	LOG ("Ephy shell finalized");
 }
 
 
@@ -539,11 +651,13 @@ load_homepage (EphyEmbed *embed)
 }
 
 /**
- * ephy_shell_new_tab:
+ * ephy_shell_new_tab_full:
  * @shell: a #EphyShell
  * @parent_window: the target #EphyWindow or %NULL
  * @previous_tab: the referrer tab or %NULL
  * @url: an url to load or %NULL
+ * @chrome: a #EphyEmbedChrome mask to use if creating a new window
+ * @user_time: a timestamp, or 0
  *
  * Create a new tab and the parent window when necessary.
  * Use this function to open urls in new window/tabs.
@@ -551,11 +665,13 @@ load_homepage (EphyEmbed *embed)
  * ReturnValue: the created #EphyTab
  **/
 EphyTab *
-ephy_shell_new_tab (EphyShell *shell,
-		    EphyWindow *parent_window,
-		    EphyTab *previous_tab,
-		    const char *url,
-		    EphyNewTabFlags flags)
+ephy_shell_new_tab_full (EphyShell *shell,
+			 EphyWindow *parent_window,
+			 EphyTab *previous_tab,
+			 const char *url,
+			 EphyNewTabFlags flags,
+			 EphyEmbedChrome chrome,
+			 guint32 user_time)
 {
 	EphyWindow *window;
 	EphyTab *tab;
@@ -575,7 +691,7 @@ ephy_shell_new_tab (EphyShell *shell,
 	jump_to = (flags & EPHY_NEW_TAB_JUMP) != 0;
 
 	LOG ("Opening new tab parent-window %p parent-tab %p in-new-window:%s jump-to:%s",
-	     parent_window, previous_tab, in_new_window ? "t" : "f", jump_to ? "t" : "f")
+	     parent_window, previous_tab, in_new_window ? "t" : "f", jump_to ? "t" : "f");
 
 	if (!in_new_window && parent_window != NULL)
 	{
@@ -583,7 +699,7 @@ ephy_shell_new_tab (EphyShell *shell,
 	}
 	else
 	{
-		window = ephy_window_new ();
+		window = ephy_window_new_with_chrome (chrome);
 	}
 
 	toolbar = EPHY_TOOLBAR (ephy_window_get_toolbar (window));
@@ -605,7 +721,8 @@ ephy_shell_new_tab (EphyShell *shell,
 	embed = ephy_tab_get_embed (tab);
 
 	ephy_window_add_tab (window, tab, position, jump_to);
-	gtk_widget_show (GTK_WIDGET (window));
+
+	ephy_gui_window_update_user_time (GTK_WIDGET (window), user_time);
 
 	if (flags & EPHY_NEW_TAB_HOME_PAGE ||
 	    flags & EPHY_NEW_TAB_NEW_PAGE)
@@ -620,6 +737,11 @@ ephy_shell_new_tab (EphyShell *shell,
 		ephy_embed_load_url (embed, url);
 	}
 
+	if ((flags & EPHY_NEW_TAB_DONT_SHOW_WINDOW) == 0)
+	{
+		gtk_widget_show (GTK_WIDGET (window));
+	}
+
 	if (flags & EPHY_NEW_TAB_FULLSCREEN_MODE)
 	{
 		gtk_window_fullscreen (GTK_WINDOW (window));
@@ -628,6 +750,30 @@ ephy_shell_new_tab (EphyShell *shell,
 	return tab;
 }
 
+/**
+ * ephy_shell_new_tab:
+ * @shell: a #EphyShell
+ * @parent_window: the target #EphyWindow or %NULL
+ * @previous_tab: the referrer tab or %NULL
+ * @url: an url to load or %NULL
+ *
+ * Create a new tab and the parent window when necessary.
+ * Use this function to open urls in new window/tabs.
+ *
+ * ReturnValue: the created #EphyTab
+ **/
+EphyTab *
+ephy_shell_new_tab (EphyShell *shell,
+		    EphyWindow *parent_window,
+		    EphyTab *previous_tab,
+		    const char *url,
+		    EphyNewTabFlags flags)
+{
+	return ephy_shell_new_tab_full (shell, parent_window,
+					previous_tab, url, flags,
+					EPHY_EMBED_CHROME_ALL, 0);
+}
+
 /**
  * ephy_shell_get_session:
  * @shell: the #EphyShell
@@ -703,12 +849,14 @@ toolbar_style_notifier (GConfClient *client,
 		flags |= new_flags;
 		egg_toolbars_model_set_flags (model, i, new_flags);
 	}
+
+	g_free (pref);
 }
 
 GObject *
 ephy_shell_get_toolbars_model (EphyShell *shell, gboolean fullscreen)
 {
-	LOG ("ephy_shell_get_toolbars_model fs=%d", fullscreen)
+	LOG ("ephy_shell_get_toolbars_model fs=%d", fullscreen);
 
 	if (fullscreen)
 	{
@@ -781,7 +929,7 @@ toolwindow_show_cb (GtkWidget *widget, EphyShell *es)
 {
 	EphySession *session;
 
-	LOG ("Ref shell for %s", G_OBJECT_TYPE_NAME (widget))
+	LOG ("Ref shell for %s", G_OBJECT_TYPE_NAME (widget));
 
 	session = EPHY_SESSION (ephy_shell_get_session (es));
 	ephy_session_add_window (ephy_shell->priv->session, GTK_WINDOW (widget));
@@ -793,7 +941,7 @@ toolwindow_hide_cb (GtkWidget *widget, EphyShell *es)
 {
 	EphySession *session;
 
-	LOG ("Unref shell for %s", G_OBJECT_TYPE_NAME (widget))
+	LOG ("Unref shell for %s", G_OBJECT_TYPE_NAME (widget));
 
 	session = EPHY_SESSION (ephy_shell_get_session (es));
 	ephy_session_remove_window (ephy_shell->priv->session, GTK_WINDOW (widget));
