@@ -18,12 +18,14 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-tab.c,v 1.123 2004/12/19 10:56:06 chpe Exp $
+ *  $Id: ephy-tab.c,v 1.137 2005/01/30 15:20:36 chpe Exp $
  */
 
 #include "config.h"
 
 #include "ephy-tab.h"
+#include "ephy-type-builtins.h"
+#include "ephy-embed-type-builtins.h"
 #include "eel-gconf-extensions.h"
 #include "ephy-prefs.h"
 #include "ephy-embed-factory.h"
@@ -61,7 +63,7 @@
 
 #define EPHY_TAB_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_TAB, EphyTabPrivate))
 
-#define CONF_LOCKDOWN_DISABLE_JAVASCRIPT_CHROME  "/apps/epiphany/lockdown/disable_javascript_chrome"
+#define MAX_HIDDEN_POPUPS 5
 
 struct _EphyTabPrivate
 {
@@ -73,7 +75,7 @@ struct _EphyTabPrivate
 	int load_percent;
 	gboolean visibility;
 	gboolean load_status;
-	TabAddressExpire address_expire;
+	EphyTabAddressExpire address_expire;
 	int cur_requests;
 	int total_requests;
 	int width;
@@ -81,11 +83,11 @@ struct _EphyTabPrivate
 	GtkToggleAction *action;
 	float zoom;
 	gboolean setting_zoom;
-	EmbedSecurityLevel security_level;
+	EphyEmbedSecurityLevel security_level;
 	GSList *hidden_popups;
 	GSList *shown_popups;
-	TabNavigationFlags nav_flags;
-	EmbedDocumentType document_type;
+	EphyTabNavigationFlags nav_flags;
+	EphyEmbedDocumentType document_type;
 };
 
 static void ephy_tab_class_init		(EphyTabClass *klass);
@@ -132,7 +134,7 @@ static void	ephy_tab_set_load_percent	(EphyTab *tab,
 static void	ephy_tab_update_navigation_flags(EphyTab *tab,
 						 EphyEmbed *embed);
 static void	ephy_tab_set_security_level	(EphyTab *tab,
-						 EmbedSecurityLevel level);
+						 EphyEmbedSecurityLevel level);
 static void	ephy_tab_set_title		(EphyTab *tab,
 						 EphyEmbed *embed,
 						 const char *new_title);
@@ -186,7 +188,7 @@ ephy_tab_set_property (GObject *object,
 	{
 		case PROP_ADDRESS:
 			ephy_tab_set_location (tab, g_value_get_string (value),
-					       TAB_ADDRESS_EXPIRE_NOW);
+					       EPHY_TAB_ADDRESS_EXPIRE_NOW);
 			break;
 		case PROP_POPUPS_ALLOWED:
 			ephy_tab_set_popups_allowed
@@ -237,10 +239,10 @@ ephy_tab_get_property (GObject *object,
 			g_value_set_string (value, ephy_tab_get_status_message (tab));
 			break;
 		case PROP_NAVIGATION:
-			g_value_set_int (value, tab->priv->nav_flags);
+			g_value_set_flags (value, tab->priv->nav_flags);
 			break;
 		case PROP_SECURITY:
-			g_value_set_int (value, tab->priv->security_level);
+			g_value_set_enum (value, tab->priv->security_level);
 			break;
 		case PROP_HIDDEN_POPUP_COUNT:
 			g_value_set_int (value, popup_blocker_n_hidden (tab));
@@ -306,6 +308,14 @@ ephy_tab_map (GtkWidget *widget)
 	GTK_WIDGET_CLASS (parent_class)->map (widget);	
 }
 
+static void
+ephy_tab_grab_focus (GtkWidget *widget)
+{
+	EphyTab *tab = EPHY_TAB (widget);
+
+	ephy_embed_activate (ephy_tab_get_embed (tab));
+}
+
 static EphyWindow *
 ephy_tab_get_window (EphyTab *tab)
 {
@@ -348,6 +358,7 @@ ephy_tab_class_init (EphyTabClass *class)
 
 	widget_class->size_allocate = ephy_tab_size_allocate;
 	widget_class->map = ephy_tab_map;
+	widget_class->grab_focus = ephy_tab_grab_focus;
 
 	g_object_class_install_property (object_class,
 					 PROP_ADDRESS,
@@ -363,7 +374,7 @@ ephy_tab_class_init (EphyTabClass *class)
 							    "Document Type",
 							    "The tab's documen type",
 							    EPHY_TYPE_EMBED_DOCUMENT_TYPE,
-							    EMBED_DOCUMENT_HTML,
+							    EPHY_EMBED_DOCUMENT_HTML,
 							    G_PARAM_READABLE));
 
 	g_object_class_install_property (object_class,
@@ -402,25 +413,21 @@ ephy_tab_class_init (EphyTabClass *class)
 
 	g_object_class_install_property (object_class,
 					 PROP_NAVIGATION,
-					 g_param_spec_int ("navigation",
-							   "Navigation flags",
-							   "The tab's navigation flags",
-							    0,
-							    TAB_NAV_UP |
-							    TAB_NAV_BACK |
-							    TAB_NAV_FORWARD,
-							    0,
-							    G_PARAM_READABLE));
+					 g_param_spec_flags ("navigation",
+							     "Navigation flags",
+							     "The tab's navigation flags",
+							     EPHY_TYPE_TAB_NAVIGATION_FLAGS,
+							     0,
+							     G_PARAM_READABLE));
 
 	g_object_class_install_property (object_class,
 					 PROP_SECURITY,
-					 g_param_spec_int ("security-level",
-							   "Security Level",
-							   "The tab's security level",
-							    STATE_IS_UNKNOWN,
-							    STATE_IS_SECURE_HIGH,
-							    STATE_IS_UNKNOWN,
-							    G_PARAM_READABLE));
+					 g_param_spec_enum ("security-level",
+							    "Security Level",
+							    "The tab's security level",
+							    EPHY_TYPE_EMBED_SECURITY_LEVEL,
+							    EPHY_EMBED_STATE_IS_UNKNOWN,
+							     G_PARAM_READABLE));
 
 	g_object_class_install_property (object_class,
 					 PROP_HIDDEN_POPUP_COUNT,
@@ -450,7 +457,7 @@ ephy_tab_class_init (EphyTabClass *class)
 
 	g_object_class_install_property (object_class,
 					 PROP_VISIBLE,
-					 g_param_spec_boolean ("visible",
+					 g_param_spec_boolean ("visibility",
 							       "Visibility",
 							       "The tab's visibility",
 							       TRUE,
@@ -485,7 +492,7 @@ popups_manager_add (EphyTab *tab,
 	PopupInfo *popup;
 
 	LOG ("popups_manager_add: tab %p, url %s, features %s",
-	     tab, url, features)
+	     tab, url, features);
 
 	g_return_if_fail (EPHY_IS_TAB (tab));
 
@@ -497,7 +504,25 @@ popups_manager_add (EphyTab *tab,
 	tab->priv->hidden_popups = g_slist_prepend
 		(tab->priv->hidden_popups, popup);
 
-	g_object_notify (G_OBJECT (tab), "hidden-popup-count");
+	if (popup_blocker_n_hidden (tab) > MAX_HIDDEN_POPUPS) /* bug #160863 */
+	{
+		/* Remove the oldest popup */
+		GSList *l = tab->priv->hidden_popups;
+
+		while (l->next->next != NULL)
+		{
+			l = l->next;
+		}
+
+		popup = (PopupInfo *) l->next->data;
+		popups_manager_free_info (popup);
+
+		l->next = NULL;
+	}
+	else
+	{
+		g_object_notify (G_OBJECT (tab), "hidden-popup-count");
+	}
 }
 
 static gboolean
@@ -522,7 +547,7 @@ static void
 popups_manager_add_window (EphyTab *tab,
 			   EphyWindow *window)
 {
-	LOG ("popups_manager_add_window: tab %p, window %p", tab, window)
+	LOG ("popups_manager_add_window: tab %p, window %p", tab, window);
 
 	g_return_if_fail (EPHY_IS_TAB (tab));
 	g_return_if_fail (EPHY_IS_WINDOW (window));
@@ -577,7 +602,7 @@ ephy_tab_get_popups_allowed (EphyTab *tab)
 
 	g_free (location);
 
-	LOG ("ephy_tab_get_popups_allowed: tab %p, allowed: %d", tab, allow)
+	LOG ("ephy_tab_get_popups_allowed: tab %p, allowed: %d", tab, allow);
 
 	return allow;
 }
@@ -603,7 +628,7 @@ popups_manager_show (PopupInfo *popup,
 static void
 popups_manager_show_all (EphyTab *tab)
 {
-	LOG ("popup_blocker_show_all: tab %p", tab)
+	LOG ("popup_blocker_show_all: tab %p", tab);
 
 	g_slist_foreach (tab->priv->hidden_popups,
 			 (GFunc) popups_manager_show, tab);
@@ -660,7 +685,7 @@ popups_manager_hide (EphyWindow *window,
 static void
 popups_manager_hide_all (EphyTab *tab)
 {
-	LOG ("popup_blocker_hide_all: tab %p", tab)
+	LOG ("popup_blocker_hide_all: tab %p", tab);
 
 	g_slist_foreach (tab->priv->shown_popups,
 			 (GFunc) popups_manager_hide, tab);
@@ -750,7 +775,7 @@ ephy_tab_finalize (GObject *object)
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 
-	LOG ("EphyTab finalized %p", tab)
+	LOG ("EphyTab finalized %p", tab);
 }
 
 static gboolean
@@ -803,12 +828,12 @@ ephy_tab_set_load_status (EphyTab *tab, gboolean status)
  *
  * Returns the type of the document loaded in @tab.
  *
- * Return value: the #EmbedDocumentType
+ * Return value: the #EphyEmbedDocumentType
  **/
-EmbedDocumentType
+EphyEmbedDocumentType
 ephy_tab_get_document_type (EphyTab *tab)
 {
-	g_return_val_if_fail (EPHY_IS_TAB (tab), EMBED_DOCUMENT_OTHER);
+	g_return_val_if_fail (EPHY_IS_TAB (tab), EPHY_EMBED_DOCUMENT_OTHER);
 
 	return tab->priv->document_type;
 }
@@ -1022,7 +1047,7 @@ ephy_tab_address_cb (EphyEmbed *embed, const char *address, EphyTab *tab)
 {
 	const char *uv_address;
 
-	LOG ("ephy_tab_address_cb tab %p address %s", tab, address)
+	LOG ("ephy_tab_address_cb tab %p address %s", tab, address);
 
 	/* Do not expose about:blank to the user, an empty address
 	   bar will do better */
@@ -1035,9 +1060,9 @@ ephy_tab_address_cb (EphyEmbed *embed, const char *address, EphyTab *tab)
 		uv_address = address;
 	}
 
-	if (tab->priv->address_expire == TAB_ADDRESS_EXPIRE_NOW)
+	if (tab->priv->address_expire == EPHY_TAB_ADDRESS_EXPIRE_NOW)
 	{
-		ephy_tab_set_location (tab, uv_address, TAB_ADDRESS_EXPIRE_NOW);
+		ephy_tab_set_location (tab, uv_address, EPHY_TAB_ADDRESS_EXPIRE_NOW);
 	}
 
 	ephy_tab_set_link_message (tab, NULL);
@@ -1082,7 +1107,7 @@ ephy_tab_content_change_cb (EphyEmbed *embed, const char *address, EphyTab *tab)
 
 static void
 ephy_tab_document_type_cb (EphyEmbed *embed,
-			   EmbedDocumentType type,
+			   EphyEmbedDocumentType type,
 			   EphyTab *tab)
 {
 	if (tab->priv->document_type != type)
@@ -1098,7 +1123,7 @@ ephy_tab_zoom_changed_cb (EphyEmbed *embed, float zoom, EphyTab *tab)
 {
 	char *address;
 
-	LOG ("ephy_tab_zoom_changed_cb tab %p zoom %f", tab, zoom)
+	LOG ("ephy_tab_zoom_changed_cb tab %p zoom %f", tab, zoom);
 
 	ephy_tab_set_zoom (tab, zoom);
 
@@ -1164,7 +1189,7 @@ build_load_percent (int requests_done, int requests_total)
 }
 
 static void
-update_net_state_message (EphyTab *tab, const char *uri, EmbedState flags)
+update_net_state_message (EphyTab *tab, const char *uri, EphyEmbedNetState flags)
 {
 	GnomeVFSURI *vfs_uri = NULL;
 	const char *msg = NULL;
@@ -1183,32 +1208,32 @@ update_net_state_message (EphyTab *tab, const char *uri, EmbedState flags)
 	if (host == NULL || host[0] == '\0') goto out;
 
 	/* IS_REQUEST and IS_NETWORK can be both set */
-	if (flags & EMBED_STATE_IS_REQUEST)
+	if (flags & EPHY_EMBED_STATE_IS_REQUEST)
 	{
-		if (flags & EMBED_STATE_REDIRECTING)
+		if (flags & EPHY_EMBED_STATE_REDIRECTING)
 		{
 			msg = _("Redirecting to %s...");
 		}
-		else if (flags & EMBED_STATE_TRANSFERRING)
+		else if (flags & EPHY_EMBED_STATE_TRANSFERRING)
 		{
 			msg = _("Transferring data from %s...");
 		}
-		else if (flags & EMBED_STATE_NEGOTIATING)
+		else if (flags & EPHY_EMBED_STATE_NEGOTIATING)
 		{
 			msg = _("Waiting for authorization from %s...");
 		}
 	}
 
-	if (flags & EMBED_STATE_IS_NETWORK)
+	if (flags & EPHY_EMBED_STATE_IS_NETWORK)
 	{
-		if (flags & EMBED_STATE_START)
+		if (flags & EPHY_EMBED_STATE_START)
 		{
 			msg = _("Loading %s...");
 		}
 	}
 
-	if ((flags & EMBED_STATE_IS_NETWORK) &&
-	    (flags & EMBED_STATE_STOP))
+	if ((flags & EPHY_EMBED_STATE_IS_NETWORK) &&
+	    (flags & EPHY_EMBED_STATE_STOP))
 	{
 		g_free (tab->priv->status_message);
 		tab->priv->status_message = NULL;
@@ -1230,17 +1255,17 @@ out:
 }
 
 static void
-build_progress_from_requests (EphyTab *tab, EmbedState state)
+build_progress_from_requests (EphyTab *tab, EphyEmbedNetState state)
 {
 	int load_percent;
 
-	if (state & EMBED_STATE_IS_REQUEST)
+	if (state & EPHY_EMBED_STATE_IS_REQUEST)
         {
-                if (state & EMBED_STATE_START)
+                if (state & EPHY_EMBED_STATE_START)
                 {
 			tab->priv->total_requests ++;
 		}
-		else if (state & EMBED_STATE_STOP)
+		else if (state & EPHY_EMBED_STATE_STOP)
 		{
 			tab->priv->cur_requests ++;
 		}
@@ -1256,9 +1281,9 @@ static void
 ensure_page_info (EphyTab *tab, EphyEmbed *embed, const char *address)
 {
 	if ((tab->priv->address == NULL || *tab->priv->address == '\0') &&
-	    tab->priv->address_expire == TAB_ADDRESS_EXPIRE_NOW)
+	    tab->priv->address_expire == EPHY_TAB_ADDRESS_EXPIRE_NOW)
         {
-		ephy_tab_set_location (tab, address, TAB_ADDRESS_EXPIRE_NOW);
+		ephy_tab_set_location (tab, address, EPHY_TAB_ADDRESS_EXPIRE_NOW);
 	}
 
 	if (tab->priv->title == NULL)
@@ -1268,14 +1293,16 @@ ensure_page_info (EphyTab *tab, EphyEmbed *embed, const char *address)
 }
 
 static void
-ephy_tab_net_state_cb (EphyEmbed *embed, const char *uri,
-		       EmbedState state, EphyTab *tab)
+ephy_tab_net_state_cb (EphyEmbed *embed,
+		       const char *uri,
+		       EphyEmbedNetState state,
+		       EphyTab *tab)
 {
 	update_net_state_message (tab, uri, state);
 
-	if (state & EMBED_STATE_IS_NETWORK)
+	if (state & EPHY_EMBED_STATE_IS_NETWORK)
 	{
-		if (state & EMBED_STATE_START)
+		if (state & EPHY_EMBED_STATE_START)
 		{
 			tab->priv->total_requests = 0;
 			tab->priv->cur_requests = 0;
@@ -1285,12 +1312,12 @@ ephy_tab_net_state_cb (EphyEmbed *embed, const char *uri,
 			ephy_tab_set_load_status (tab, TRUE);
 			ephy_tab_update_navigation_flags (tab, embed);
 		}
-		else if (state & EMBED_STATE_STOP)
+		else if (state & EPHY_EMBED_STATE_STOP)
 		{
 			ephy_tab_set_load_percent (tab, 100);
 			ephy_tab_set_load_status (tab, FALSE);
 			ephy_tab_update_navigation_flags (tab, embed);
-			tab->priv->address_expire = TAB_ADDRESS_EXPIRE_NOW;
+			tab->priv->address_expire = EPHY_TAB_ADDRESS_EXPIRE_NOW;
 		}
 	}
 
@@ -1298,30 +1325,16 @@ ephy_tab_net_state_cb (EphyEmbed *embed, const char *uri,
 }
 
 static void
-ephy_tab_new_window_cb (EphyEmbed *embed, EphyEmbed **new_embed,
-			EphyEmbedChrome chromemask, EphyTab *tab)
+ephy_tab_new_window_cb (EphyEmbed *embed,
+			EphyEmbed *new_embed,
+			EphyTab *tab)
 {
-	EphyTab *new_tab;
 	EphyWindow *window;
 
-	LOG ("ephy_tab_new_window_cb tab %p with parent %p chrome %d",
-	     tab, ((GtkWidget *) tab)->parent, chromemask)
+	g_return_if_fail (new_embed != NULL);
 
-	if (eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_JAVASCRIPT_CHROME))
-	{
-		window = ephy_window_new ();
-	}
-	else
-	{
-		window = ephy_window_new_with_chrome (chromemask);
-	}
-
-	new_tab = ephy_tab_new ();
-	gtk_widget_show (GTK_WIDGET (new_tab));
-
-        ephy_window_add_tab (window, new_tab, -1, FALSE);
-
-	*new_embed = ephy_tab_get_embed (new_tab);
+	window = EPHY_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (new_embed)));
+	g_return_if_fail (window != NULL);
 
 	popups_manager_add_window (tab, window);
 }
@@ -1346,7 +1359,7 @@ ephy_tab_visibility_cb (EphyEmbed *embed, gboolean visibility,
 			EphyTab *tab)
 {
 	LOG ("ephy_tab_visibility_cb tab %p visibility %d",
-	     tab, visibility)
+	     tab, visibility);
 
 	if (visibility)
 	{
@@ -1359,7 +1372,7 @@ ephy_tab_visibility_cb (EphyEmbed *embed, gboolean visibility,
 
 	tab->priv->visibility = visibility;
 
-	g_object_notify (G_OBJECT (tab), "visible");
+	g_object_notify (G_OBJECT (tab), "visibility");
 }
 
 static void
@@ -1371,7 +1384,7 @@ ephy_tab_destroy_brsr_cb (EphyEmbed *embed, EphyTab *tab)
 	g_return_if_fail (EPHY_IS_TAB (tab));
 
 	LOG ("ephy_tab_destroy_browser_cb tab %p parent %p",
-	     tab, ((GtkWidget *) tab)->parent)
+	     tab, ((GtkWidget *) tab)->parent);
 
 	window = ephy_tab_get_window (tab);
 	g_return_if_fail (window != NULL);
@@ -1389,7 +1402,7 @@ ephy_tab_size_to_cb (EphyEmbed *embed, gint width, gint height,
 	GtkWidget *notebook;
 	EphyWindow *window;
 
-	LOG ("ephy_tab_size_to_cb tab %p width %d height %d", tab, width, height)
+	LOG ("ephy_tab_size_to_cb tab %p width %d height %d", tab, width, height);
 
 	tab->priv->width = width;
 	tab->priv->height = height;
@@ -1491,9 +1504,8 @@ ephy_tab_dom_mouse_click_cb (EphyEmbed *embed,
 			     EphyEmbedEvent *event,
 			     EphyTab *tab)
 {
-	EphyEmbedEventType type;
-	EmbedEventContext context;
-	guint modifier;
+	EphyEmbedEventContext context;
+	guint button, modifier;
 	gboolean handled = TRUE;
 	gboolean with_control, with_shift, is_left_click, is_middle_click;
 	gboolean is_link, is_image, is_middle_clickable;
@@ -1502,28 +1514,28 @@ ephy_tab_dom_mouse_click_cb (EphyEmbed *embed,
 
 	g_return_val_if_fail (EPHY_IS_EMBED_EVENT(event), FALSE);
 
-	type = ephy_embed_event_get_event_type (event);
+	button = ephy_embed_event_get_button (event);
 	context = ephy_embed_event_get_context (event);
 	modifier = ephy_embed_event_get_modifier (event);
 
-	LOG ("ephy_tab_dom_mouse_click_cb: type %d, context %x, modifier %x",
-	     type, context, modifier)
+	LOG ("ephy_tab_dom_mouse_click_cb: button %d, context %x, modifier %x",
+	     button, context, modifier);
 
 	with_control = (modifier & GDK_CONTROL_MASK) != 0;
 	with_shift = (modifier & GDK_SHIFT_MASK) != 0;
-	is_left_click = (type == EPHY_EMBED_EVENT_MOUSE_BUTTON1);
-	is_middle_click = (type == EPHY_EMBED_EVENT_MOUSE_BUTTON2);
+	is_left_click = (button == 1);
+	is_middle_click = (button == 2);
 
 	middle_click_opens =
 		eel_gconf_get_boolean (CONF_INTERFACE_MIDDLE_CLICK_OPEN_URL) &&
 		!eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_ARBITRARY_URL);
 
-	is_link = (context & EMBED_CONTEXT_LINK) != 0;
-	is_image = (context & EMBED_CONTEXT_IMAGE) != 0;
-	is_middle_clickable = !((context & EMBED_CONTEXT_LINK)
-				|| (context & EMBED_CONTEXT_INPUT)
-				|| (context & EMBED_CONTEXT_EMAIL_LINK));
-	is_input = (context & EMBED_CONTEXT_INPUT) != 0;
+	is_link = (context & EPHY_EMBED_CONTEXT_LINK) != 0;
+	is_image = (context & EPHY_EMBED_CONTEXT_IMAGE) != 0;
+	is_middle_clickable = !((context & EPHY_EMBED_CONTEXT_LINK)
+				|| (context & EPHY_EMBED_CONTEXT_INPUT)
+				|| (context & EPHY_EMBED_CONTEXT_EMAIL_LINK));
+	is_input = (context & EPHY_EMBED_CONTEXT_INPUT) != 0;
 
 	/* ctrl+click or middle click opens the link in new tab */
 	if (is_link && ((is_left_click && with_control) || is_middle_click))
@@ -1577,7 +1589,7 @@ ephy_tab_dom_mouse_click_cb (EphyEmbed *embed,
 }
 
 static void
-ephy_tab_security_change_cb (EphyEmbed *embed, EmbedSecurityLevel level,
+ephy_tab_security_change_cb (EphyEmbed *embed, EphyEmbedSecurityLevel level,
 			       EphyTab *tab)
 {
 	ephy_tab_set_security_level (tab, level);
@@ -1590,7 +1602,7 @@ ephy_tab_init (EphyTab *tab)
 	EphyFaviconCache *cache;
 	char *id;
 
-	LOG ("EphyTab initialising %p", tab)
+	LOG ("EphyTab initialising %p", tab);
 
 	tab->priv = EPHY_TAB_GET_PRIVATE (tab);
 
@@ -1600,10 +1612,10 @@ ephy_tab_init (EphyTab *tab)
 	tab->priv->height = -1;
 	tab->priv->load_percent = 0;
 	tab->priv->load_status = FALSE;
-	tab->priv->security_level = STATE_IS_UNKNOWN;
-	tab->priv->document_type = EMBED_DOCUMENT_HTML;
+	tab->priv->security_level = EPHY_EMBED_STATE_IS_UNKNOWN;
+	tab->priv->document_type = EPHY_EMBED_DOCUMENT_HTML;
 	tab->priv->zoom = 1.0;
-	tab->priv->address_expire = TAB_ADDRESS_EXPIRE_NOW;
+	tab->priv->address_expire = EPHY_TAB_ADDRESS_EXPIRE_NOW;
 
 	embed = ephy_embed_factory_new_object (EPHY_TYPE_EMBED);
 	g_assert (embed != NULL);
@@ -1715,21 +1727,21 @@ ephy_tab_get_load_percent (EphyTab *tab)
 static void
 ephy_tab_update_navigation_flags (EphyTab *tab, EphyEmbed *embed)
 {
-	TabNavigationFlags flags = 0;
+	EphyTabNavigationFlags flags = 0;
 
 	if (ephy_embed_can_go_up (embed))
 	{
-		flags |= TAB_NAV_UP;
+		flags |= EPHY_TAB_NAV_UP;
 	}
 
 	if (ephy_embed_can_go_back (embed))
 	{
-		flags |= TAB_NAV_BACK;
+		flags |= EPHY_TAB_NAV_BACK;
 	}
 
 	if (ephy_embed_can_go_forward (embed))
 	{
-		flags |= TAB_NAV_FORWARD;
+		flags |= EPHY_TAB_NAV_FORWARD;
 	}
 
 	if (flags != tab->priv->nav_flags)
@@ -1748,7 +1760,7 @@ ephy_tab_update_navigation_flags (EphyTab *tab, EphyEmbed *embed)
  *
  * Return value: @tab's navigation flags
  **/
-TabNavigationFlags
+EphyTabNavigationFlags
 ephy_tab_get_navigation_flags (EphyTab *tab)
 {
 	g_return_val_if_fail (EPHY_IS_TAB (tab), 0);
@@ -1900,17 +1912,17 @@ ephy_tab_get_location (EphyTab *tab)
 void
 ephy_tab_set_location (EphyTab *tab,
 		       const char *address,
-		       TabAddressExpire expire)
+		       EphyTabAddressExpire expire)
 {
 	g_return_if_fail (EPHY_IS_TAB (tab));
 
 	if (tab->priv->address) g_free (tab->priv->address);
 	tab->priv->address = g_strdup (address);
 
-	if (expire == TAB_ADDRESS_EXPIRE_CURRENT &&
+	if (expire == EPHY_TAB_ADDRESS_EXPIRE_CURRENT &&
 	    !tab->priv->load_status)
 	{
-		tab->priv->address_expire = TAB_ADDRESS_EXPIRE_NOW;
+		tab->priv->address_expire = EPHY_TAB_ADDRESS_EXPIRE_NOW;
 	}
 	else
 	{
@@ -1921,7 +1933,7 @@ ephy_tab_set_location (EphyTab *tab,
 }
 
 static void
-ephy_tab_set_security_level (EphyTab *tab, EmbedSecurityLevel level)
+ephy_tab_set_security_level (EphyTab *tab, EphyEmbedSecurityLevel level)
 {
 	g_return_if_fail (EPHY_IS_TAB (tab));
 
@@ -1938,10 +1950,10 @@ ephy_tab_set_security_level (EphyTab *tab, EmbedSecurityLevel level)
  *
  * Return value: @tab's loaded page's security level
  **/
-EmbedSecurityLevel
+EphyEmbedSecurityLevel
 ephy_tab_get_security_level (EphyTab *tab)
 {
-	g_return_val_if_fail (EPHY_IS_TAB (tab), STATE_IS_UNKNOWN);
+	g_return_val_if_fail (EPHY_IS_TAB (tab), EPHY_EMBED_STATE_IS_UNKNOWN);
 
 	return tab->priv->security_level;
 }
