@@ -16,12 +16,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-tabs-menu.c,v 1.31 2004/12/13 18:58:58 chpe Exp $
+ *  $Id: ephy-tabs-menu.c,v 1.33 2005/01/28 22:24:46 chpe Exp $
  */
 
 #include "config.h"
 
 #include "ephy-tabs-menu.h"
+#include "ephy-notebook.h"
 #include "ephy-marshal.h"
 #include "ephy-shell.h"
 #include "ephy-debug.h"
@@ -300,7 +301,7 @@ ephy_tabs_menu_update (EphyTabsMenu *menu)
 	guint i = 0;
 	GList *tabs = NULL, *l;
 
-	LOG ("Rebuilding open tabs menu")
+	LOG ("Rebuilding open tabs menu");
 
 	START_PROFILER ("Rebuilding tabs menu")
 
