@@ -16,12 +16,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-toolbars-model.c,v 1.32 2004/10/23 16:49:10 chpe Exp $
+ *  $Id: ephy-toolbars-model.c,v 1.35 2005/01/28 22:24:46 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-toolbars-model.h"
 #include "ephy-file-helpers.h"
@@ -34,7 +32,7 @@
 
 #define EPHY_TOOLBARS_MODEL_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_TOOLBARS_MODEL, EphyToolbarsModelPrivate))
 
-struct EphyToolbarsModelPrivate
+struct _EphyToolbarsModelPrivate
 {
 	char *xml_file;
 	guint timeout;
@@ -75,7 +73,7 @@ ephy_toolbars_model_get_type (void)
 static gboolean
 save_changes_idle (EphyToolbarsModel *model)
 {
-	LOG ("Saving toolbars model")
+	LOG ("Saving toolbars model");
 
 	egg_toolbars_model_save
 		(EGG_TOOLBARS_MODEL (model),
@@ -159,7 +157,7 @@ ephy_toolbars_model_load (EphyToolbarsModel *model)
 	gboolean success;
 
 	success = egg_toolbars_model_load (eggmodel, model->priv->xml_file);
-	LOG ("Loading the toolbars was %ssuccessful", success ? "" : "un")
+	LOG ("Loading the toolbars was %ssuccessful", success ? "" : "un");
 
 	/* maybe an old format, try to migrate: load the old layout, and
 	 * remove the BookmarksBar toolbar
@@ -184,7 +182,7 @@ ephy_toolbars_model_load (EphyToolbarsModel *model)
 			}
 		}
 
-		LOG ("Migration was %ssuccessful", success ? "" : "un")
+		LOG ("Migration was %ssuccessful", success ? "" : "un");
 	}
 
 	/* Still no success, load the default toolbars */
@@ -192,7 +190,7 @@ ephy_toolbars_model_load (EphyToolbarsModel *model)
 	{
 		success = egg_toolbars_model_load
 				(eggmodel, ephy_file ("epiphany-toolbar.xml"));
-		LOG ("Loading the default toolbars was %ssuccessful", success ? "" : "un")
+		LOG ("Loading the default toolbars was %ssuccessful", success ? "" : "un");
 	}
 
 	/* Ensure we have at least 1 toolbar */
